@@ -33,7 +33,7 @@ struct data;
  */
 struct base_resolution_psp {
 	typedef boost::shared_ptr< base_resolution_psp >    ptr;             ///< Pointer to position-specific prior.
-	typedef long unsigned int                           pos_t;           ///< Type that identifies a position.
+	typedef long unsigned int                         pos_t;           ///< Type that identifies a position.
 
 	/// Return the maximal PSP for all the bases in the given range
 	virtual
@@ -172,7 +172,7 @@ template< typename Spec >
 struct psp {
 
     typedef boost::shared_ptr< psp >    ptr;             ///< Pointer to position-specific prior.
-    typedef long unsigned int           pos_t;           ///< Type that identifies a position.
+    typedef long unsigned int         pos_t;           ///< Type that identifies a position.
     STEME_TYPEDEF_SEQAN_TYPES( Spec )
 
     /// Return g at the given position.
@@ -301,7 +301,6 @@ struct dense_psp
 , boost::noncopyable
 , model_priors_calculator< dense_psp< Spec >, Spec >
 {
-    typedef Spec                                 spec;            ///< Specification.
     typedef typename psp< Spec >::pos_t          pos_t;           ///< Index into a position.
     typedef data< Spec >                         data_t;          ///< The data type.
     typedef seqan::String< double >              vertex_g_vec;    ///< Vector of weights indexed by suffix array vertex.
@@ -383,13 +382,12 @@ struct sparse_psp
 , boost::noncopyable
 , model_priors_calculator< sparse_psp< Spec >, Spec >
 {
-    typedef Spec                                               spec;            ///< Specification.
-    typedef typename psp< Spec >::pos_t                        pos_t;           ///< Index into a position.
+    typedef typename psp< Spec >::pos_t                       pos_t;           ///< Index into a position.
     typedef data< Spec >                                       data_t;          ///< The data type.
-    typedef int                                                vertex_id_t;     ///< Type that identifies a vertex.
+    typedef unsigned long                                     vertex_id_t;     ///< Type that identifies a vertex.
     typedef std::map< vertex_id_t, double >                    vertex_g_map;    ///< Map from vertices to weights.
     typedef std::map< pos_t, double >                          pos_g_map;       ///< Map from positions to weights.
-    typedef std::vector< pos_g_map >                           vec_pos_g_maps;  ///< Vector of maps from positions to weights.
+    typedef std::vector< pos_g_map >                            vec_pos_g_maps;  ///< Vector of maps from positions to weights.
     STEME_TYPEDEF_SEQAN_TYPES( Spec )
 
 protected:
@@ -481,7 +479,7 @@ public:
      * Is faster than the previous method that used posLocalize to get to a local position first.
      */
     infix_t
-    get_W_mer( size_t W, int pos ) {
+    get_W_mer( size_t W, global_pos_t pos ) {
         return seqan::infixWithLength( concatenated_seqs, pos, W );
     }
 };
@@ -504,10 +502,10 @@ public:
      * Get the W-mer that starts at the given index.
      */
     infix_t
-    get_W_mer( size_t W, int pos ) {
+    get_W_mer( size_t W, global_pos_t pos ) {
         using namespace seqan;
-        id_t id;
-        int offset;
+        seq_index_t id;
+        seq_offset_t offset;
         boost::tie( id, offset ) = static_cast< Derived * >( this )->pos_localise( pos );
 #ifdef MS_DO_DEBUG_CHECKS
         if( offset < 0 || length( getValueById( static_cast< Derived * >( this )->get_text(), id ) ) < offset + W ) {
@@ -746,14 +744,14 @@ struct data
 	/** Do 2 global positions overlap? */
 	static
 	bool
-	overlap( size_t W , int pos1, int pos2 ) {
+	overlap( size_t W , global_pos_t pos1, global_pos_t pos2 ) {
 		return wmer_overlap( pos1, pos2, W );
 	}
 
 
 	/** Returns a tuple: sequence id, offset for a global position. */
 	local_pos_t
-	pos_localise( int pos ) {
+	pos_localise( global_pos_t pos ) {
 		using namespace seqan;
 		sa_value_t local_pos;
 		posLocalize( local_pos, pos, get_string_set_limits() );
@@ -765,9 +763,9 @@ struct data
 
 
 	/** Converts a local position to a global position. */
-	int
-	pos_globalise( id_t id, int offset ) {
-		return seqan::posGlobalize( seqan::Pair< int, int >( id, offset ), get_string_set_limits() );
+	global_pos_t
+	pos_globalise( seq_index_t id, seq_offset_t offset ) {
+		return seqan::posGlobalize( sa_value_t( id, offset ), get_string_set_limits() );
 	}
 
 
